package de.thdeg.grademanager.model;

import jakarta.persistence.*;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

@Entity
@Table(name = "Studiengang")
public class CoursesOfStudy
{
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "ID")
    private int id;

    @Column(name = "Name")
    private String name;

    @Column(name = "Abschluss")
    private String degree;

    @Column(name = "Dauer")
    private int duration;

    @Column(name = "Studiengebühr")
    private int fees;

    @Column(name = "Schwerpunkt")
    private String fieldOfStudy;

    @OneToMany(
            mappedBy = "coursesOfStudy",
            cascade = CascadeType.ALL,
            orphanRemoval = true
    )
    private List<Course> courses = new ArrayList<>();
    @ManyToOne
    @JoinColumn(name = "courses_of_study_id")
    private CoursesOfStudy coursesOfStudy;

    public List<Course> getCourses() {
        return courses;
    }

    /*
    @ManyToOne(cascade = CascadeType.ALL)
    @JoinColumn(name = "courses_of_study_id")
    private CoursesOfStudy coursesOfStudy;
    */

    public CoursesOfStudy()
    {

    }

    public CoursesOfStudy(String name, String degree, int duration, int fees, String fieldOfStudy)
    {
        this.name = name;
        this.degree = degree;
        this.duration = duration;
        this.fees = fees;
        this.fieldOfStudy = fieldOfStudy;
    }

    @Override
    public boolean equals(Object o)
    {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        CoursesOfStudy that = (CoursesOfStudy) o;
        return id == that.id;
    }

    @Override
    public int hashCode()
    {
        return Objects.hash(id);
    }

    public int getId()
    {
        return id;
    }

    public void setId(int id)
    {
        this.id = id;
    }

    public String getName()
    {
        return name;
    }

    public void setName(String name)
    {
        this.name = name;
    }

    public String getDegree()
    {
        return degree;
    }

    public void setDegree(String degree)
    {
        this.degree = degree;
    }

    public int getDuration()
    {
        return duration;
    }

    public void setDuration(int duration)
    {
        this.duration = duration;
    }

    public int getFees()
    {
        return fees;
    }

    public void setFees(int fees)
    {
        this.fees = fees;
    }

    public String getFieldOfStudy()
    {
        return fieldOfStudy;
    }

    public void setFieldOfStudy(String fieldOfStudy)
    {
        this.fieldOfStudy = fieldOfStudy;
    }

    public void addCourse(Course course)
    {
        courses.add(course);
        course.setCoursesOfStudy(this);
    }

    public void removeCourse(Course course)
    {
        courses.remove(course);
        course.setCoursesOfStudy(null);
    }
}
